@@ -151,6 +151,8 @@ def delete(args, syn):
     
 def add(args, syn):
     if args.type == 'File': args.type = 'FileEntity'
+    if args.file and not args.name:
+        args.name = utils.guess_file_name(args.file)
     entity = {'name': args.name,
               'parentId': args.parentid,
               'description':args.description,
@@ -221,13 +223,69 @@ def getProvenance(args, syn):
     
     
 def submit(args, syn):
-    if args.name is not None: args.name = ' '.join(args.name)
+    '''
+    Method to allow challenge participants to submit to an evaluation queue
     
-    submission = syn.submit(args.evaluation, args.entity, name=args.name, teamName=args.teamName)
-    print 'Submitted (id: %s) entity: %s\t%s to Evaluation: %s\n' \
-            % (submission['id'], submission['entityId'], submission['name'], submission['evaluationId'])
-
-
+    Examples:
+    1. #submit to a eval Queue by eval ID , uploading the submission file
+    synapse submit --evalID 2343117 -f ~/testing/testing.txt --pid syn2345030 --used syn2351967 --executed syn2351968
+    
+    2. support for deprecated --evaluation option
+    synapse submit --evaluation 'ra_challenge_Q1_leaderboard' -f ~/testing/testing.txt --pid syn2345030 --used syn2351967 --executed syn2351968
+    synapse submit --evaluation 2343117 -f ~/testing/testing.txt --pid syn2345030 --used syn2351967 --executed syn2351968
+    
+    '''
+    
+    #backward compatibility support
+    if args.evaluation is not None:
+        sys.stdout.write('[Warning]: Use of --evaluation is deprecated. Use -evalId or -evalName \n')
+        #check if evaluation is a number, if so it is assumed to be a evaluationId else it is a evaluationName
+        try:
+            args.evaluationID = str(int(args.evaluation))
+        except ValueError:
+            args.evaluationName = args.evaluation
+    
+    #set the user teamname to username if none is specified
+    if args.teamName is None:
+        args.teamName = syn.getUserProfile()['userName']
+        
+    # checking if user has entered a evaluation ID or evaluation Name
+    if args.evaluationID is None and args.evaluationName is None:
+        raise ValueError('Evaluation ID or Evaluation Name is required\n')
+    elif args.evaluationID is not None and args.evaluationName is not None:
+        sys.stderr.write('[Warning]: Both Evaluation ID & Evaluation Name are specified \n EvaluationID will be used\n')
+    elif args.evaluationID is None: #get evalID from evalName
+        try:
+            args.evaluationID = syn.getEvaluationByName(args.evaluationName)['id']
+        except Exception as e:
+            raise ValueError('could not find evaluationID for evaluationName: %s \n' % args.evaluationName)
+    
+    
+    # checking if a entity id or file was specified by the user
+    if args.entity is None and args.file is None:
+        raise ValueError('Either entityID or filename is required for a submission\n')
+    elif args.entity is not  None and args.file is not None:
+        sys.stderr.write('[Warning]: Both entityID and filename are specified \n entityID will be used\n')
+    elif args.entity is None: #upload the the file to synapse and get synapse entity id for the file
+        if args.parentId is None:
+            raise ValueError('parentID required with a file upload\n')
+        if not os.path.exists(args.file):
+            raise IOError('file path %s not valid \n' % args.file)
+        # //ideally this should be factored out
+        try:
+            synFile = syn.store(synapseclient.File(path=args.file,parent=args.parentId),
+                                used=args.used, executed=args.executed)
+            args.entity = synFile.id
+        except Exception as e:
+            raise SynapseError('Unable to upload file %s to synapse \n' % args.file)
+    try:    
+        submission = syn.submit(args.evaluationID, args.entity, name=args.name, teamName=args.teamName)
+        sys.stdout.write('Submitted (id: %s) entity: %s\t%s to Evaluation: %s\n' \
+            % (submission['id'], submission['entityId'], submission['name'], submission['evaluationId']))
+    except Exception as e:
+        raise SynapseError('Unable to successfully submit to the evaluation %s \n' % args.evaluationID)
+        
+        
 def login(args, syn):
     """Log in to Synapse, optionally caching credentials"""
     syn.login(args.synapseUser, args.synapsePassword, rememberMe=args.rememberMe)
@@ -343,23 +401,47 @@ def build_parser():
     
     parser_submit = subparsers.add_parser(
             'submit',
-            help='submit an entity for evaluation')
+            help='submit an entity or a file for evaluation')
+    parser_submit.add_argument(
+            '--evaluationID', '--evalID',
+            type=str,
+            help='Evaluation ID where the entity/file will be submitted')
+    parser_submit.add_argument(
+            '--evaluationName', '--evalN',
+            type=str,
+            help='Evaluation Name where the entity/file will be submitted')
     parser_submit.add_argument(
             '--evaluation',
-            type=str, required=True,
-            help='Evaluation ID where the entity will be submitted')
+            type=str,
+            help=argparse.SUPPRESS)  #mainly to maintain the backward compatibility
     parser_submit.add_argument(
-            '--entity',
-            type=str, required=True,
+            '--entity', '--eid',
+            type=str,
             help='Synapse ID of the entity to be submitted')
+    parser_submit.add_argument(
+            '--file', '-f',
+            type=str,
+            help='File to be submitted to the challenge')
+    parser_submit.add_argument(
+            '--parentId', '--pid',
+            type=str,
+            help='Synapse ID of project or folder where to upload data')
     parser_submit.add_argument(
             '--name',
-            type=str, nargs="+",
+            type=str,
             help='Name of the submission')
     parser_submit.add_argument(
             '--teamName', '--team',
             type=str,
-            help='Publicly displayed name of team for the submission')
+            help='Publicly displayed name of team for the submission[defaults to username]')
+    parser_submit.add_argument(
+            '--used',
+            metavar='TargetID', type=str, nargs='*',
+            help='ID of a target data entity from which the specified entity is derived')
+    parser_submit.add_argument(
+            '--executed',
+            metavar='TargetID', type=str, nargs='*',
+            help='ID of a code entity from which the specified entity is derived')
     parser_submit.set_defaults(func=submit)
 
     
@@ -428,7 +510,6 @@ def build_parser():
             help='Output the provenance record in JSON format')
     parser_get_provenance.set_defaults(func=getProvenance)
 
-
     parser_add = subparsers.add_parser(
             'add',
             help='uploads and adds a dataset to Synapse')
